@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2012 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -86,7 +86,7 @@ positiiviset kommentit otetaan ilolla vastaan.
 #ifndef TRANSLATOR_FI_H
 #define TRANSLATOR_FI_H
 
-class TranslatorFinnish : public Translator
+class TranslatorFinnish : public TranslatorAdapter_1_6_0
 {
   public:
     /*! This method is used to generate a warning message to signal
@@ -182,7 +182,7 @@ class TranslatorFinnish : public Translator
 
      /*! put in the class documentation */
     virtual QCString trListOfAllMembers()
-    { return "Lista kaikista jäsenistä."; } // "List of all members."
+    { return "Lista kaikista jäsenistä"; } // "List of all members."
     virtual QCString trMemberList()
 
     /*! used as the title of the "list of all members" page of a class */
